Tensorflow Layers
*****************

MCLSTM
========
.. autoclass:: ai4water.models.tensorflow.MCLSTM
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__


Conditionalize
========
.. autoclass:: ai4water.models.tensorflow.Conditionalize
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

EALSTM
========
.. autoclass:: ai4water.models.tensorflow.EALSTM
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
